@@ -1,9 +1,10 @@
 mod blob {
+    /*
     use std::sync::Arc;
     use std::time::Duration;
 
     use crate::condow_client::NoLocation;
-    use crate::reporter::SimpleReporterFactory;
+    use crate::probe::SimpleReporterFactory;
     use crate::{config::Config, test_utils::*, Condow};
 
     use crate::test_utils::create_test_data;
@@ -68,7 +69,7 @@ mod blob {
                     let condow = Condow::new(client.clone(), config).unwrap();
 
                     let downloader =
-                        condow.downloader_with_reporting(SimpleReporterFactory::default());
+                        condow.blob().probe(SimpleReporterFactory::default());
 
                     let result_stream = downloader.download_rep(NoLocation, ..).await.unwrap();
 
@@ -77,16 +78,15 @@ mod blob {
                 }
             }
         }
-    }
+    }*/
 }
 
 mod range {
     mod open {
         use std::sync::Arc;
 
-        use crate::condow_client::NoLocation;
+        use crate::condow_client::IgnoreLocation;
         use crate::machinery;
-        use crate::reporter::SimpleReporter;
         use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
         #[tokio::test]
@@ -115,17 +115,17 @@ mod range {
                         for from_idx in [0u64, 101, 255, 256] {
                             let range = from_idx..;
 
-                            let result_stream = machinery::download(
-                                &condow,
-                                NoLocation,
+                            let result_stream = machinery::download_range(
+                                condow.clone(),
+                                IgnoreLocation,
                                 range.clone(),
                                 crate::GetSizeMode::Always,
-                                SimpleReporter::default(),
+                                Default::default(),
                             )
                             .await
                             .unwrap();
 
-                            let result = result_stream.into_stream().into_vec().await.unwrap();
+                            let result = result_stream.into_vec().await.unwrap();
 
                             let check_range = (from_idx as usize).min(data.len())..;
                             assert_eq!(&result, &data[check_range]);
@@ -161,17 +161,15 @@ mod range {
                         for from_idx in [0u64, 101, 255, 256] {
                             let range = from_idx..;
 
-                            let result_stream = machinery::download(
-                                &condow,
-                                NoLocation,
-                                range.clone(),
-                                crate::GetSizeMode::Required,
-                                SimpleReporter::default(),
-                            )
-                            .await
-                            .unwrap();
+                            let result_stream = condow
+                                .blob()
+                                .get_size_mode(crate::GetSizeMode::Required)
+                                .range(range)
+                                .download_chunks()
+                                .await
+                                .unwrap();
 
-                            let result = result_stream.into_stream().into_vec().await.unwrap();
+                            let result = result_stream.into_vec().await.unwrap();
 
                             let check_range = (from_idx as usize).min(data.len())..;
                             assert_eq!(&result, &data[check_range]);
@@ -185,9 +183,8 @@ mod range {
     mod closed {
         use std::sync::Arc;
 
-        use crate::condow_client::NoLocation;
+        use crate::condow_client::IgnoreLocation;
         use crate::machinery;
-        use crate::reporter::SimpleReporter;
         use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
         #[tokio::test]
@@ -217,17 +214,17 @@ mod range {
                             let range = 0..=end_incl;
                             let expected_range_end = (end_incl as usize + 1).min(data.len());
 
-                            let result_stream = machinery::download(
-                                &condow,
-                                NoLocation,
+                            let result_stream = machinery::download_range(
+                                condow.clone(),
+                                IgnoreLocation,
                                 range.clone(),
                                 crate::GetSizeMode::Default,
-                                SimpleReporter::default(),
+                                Default::default(),
                             )
                             .await
                             .unwrap();
 
-                            let result = result_stream.into_stream().into_vec().await.unwrap();
+                            let result = result_stream.into_vec().await.unwrap();
 
                             assert_eq!(&result, &data[0..expected_range_end]);
                         }
@@ -263,17 +260,17 @@ mod range {
                             let range = 0..end_excl;
                             let expected_range_end = (end_excl as usize).min(data.len());
 
-                            let result_stream = machinery::download(
-                                &condow,
-                                NoLocation,
+                            let result_stream = machinery::download_range(
+                                condow.clone(),
+                                IgnoreLocation,
                                 range.clone(),
                                 crate::GetSizeMode::Default,
-                                SimpleReporter::default(),
+                                Default::default(),
                             )
                             .await
                             .unwrap();
 
-                            let result = result_stream.into_stream().into_vec().await.unwrap();
+                            let result = result_stream.into_vec().await.unwrap();
 
                             assert_eq!(&result, &data[0..expected_range_end]);
                         }
@@ -286,9 +283,8 @@ mod range {
             mod start_at_0 {
                 use std::sync::Arc;
 
-                use crate::condow_client::NoLocation;
+                use crate::condow_client::IgnoreLocation;
                 use crate::machinery;
-                use crate::reporter::SimpleReporter;
                 use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
                 #[tokio::test]
@@ -319,18 +315,17 @@ mod range {
                                     let expected_range_end =
                                         (end_incl as usize + 1).min(data.len());
 
-                                    let result_stream = machinery::download(
-                                        &condow,
-                                        NoLocation,
+                                    let result_stream = machinery::download_range(
+                                        condow.clone(),
+                                        IgnoreLocation,
                                         range,
                                         crate::GetSizeMode::Default,
-                                        SimpleReporter::default(),
+                                        Default::default(),
                                     )
                                     .await
                                     .unwrap();
 
-                                    let result =
-                                        result_stream.into_stream().into_vec().await.unwrap();
+                                    let result = result_stream.into_vec().await.unwrap();
 
                                     assert_eq!(&result, &data[0..expected_range_end]);
                                 }
@@ -366,18 +361,17 @@ mod range {
                                     let range = 0..end_excl;
                                     let expected_range_end = (end_excl as usize).min(data.len());
 
-                                    let result_stream = machinery::download(
-                                        &condow,
-                                        NoLocation,
+                                    let result_stream = machinery::download_range(
+                                        condow.clone(),
+                                        IgnoreLocation,
                                         range,
                                         crate::GetSizeMode::Default,
-                                        SimpleReporter::default(),
+                                        Default::default(),
                                     )
                                     .await
                                     .unwrap();
 
-                                    let result =
-                                        result_stream.into_stream().into_vec().await.unwrap();
+                                    let result = result_stream.into_vec().await.unwrap();
 
                                     assert_eq!(&result, &data[0..expected_range_end]);
                                 }
@@ -390,9 +384,8 @@ mod range {
             mod start_after_0 {
                 use std::sync::Arc;
 
-                use crate::condow_client::NoLocation;
+                use crate::condow_client::IgnoreLocation;
                 use crate::machinery;
-                use crate::reporter::SimpleReporter;
                 use crate::{config::Config, test_utils::create_test_data, test_utils::*, Condow};
 
                 #[tokio::test]
@@ -425,18 +418,17 @@ mod range {
                                         let expected_range_end =
                                             (end_incl as usize + 1).min(data.len());
 
-                                        let result_stream = machinery::download(
-                                            &condow,
-                                            NoLocation,
+                                        let result_stream = machinery::download_range(
+                                            condow.clone(),
+                                            IgnoreLocation,
                                             range,
                                             crate::GetSizeMode::Default,
-                                            SimpleReporter::default(),
+                                            Default::default(),
                                         )
                                         .await
                                         .unwrap();
 
-                                        let result =
-                                            result_stream.into_stream().into_vec().await.unwrap();
+                                        let result = result_stream.into_vec().await.unwrap();
 
                                         assert_eq!(
                                             &result,
@@ -479,18 +471,17 @@ mod range {
                                         let expected_range_end =
                                             (end_excl as usize).min(data.len());
 
-                                        let result_stream = machinery::download(
-                                            &condow,
-                                            NoLocation,
+                                        let result_stream = machinery::download_range(
+                                            condow.clone(),
+                                            IgnoreLocation,
                                             range,
                                             crate::GetSizeMode::Default,
-                                            SimpleReporter::default(),
+                                            Default::default(),
                                         )
                                         .await
                                         .unwrap();
 
-                                        let result =
-                                            result_stream.into_stream().into_vec().await.unwrap();
+                                        let result = result_stream.into_vec().await.unwrap();
 
                                         assert_eq!(
                                             &result,
